Index: trunk/softs/tsar_boot/Makefile
===================================================================
--- trunk/softs/tsar_boot/Makefile	(revision 1048)
+++ trunk/softs/tsar_boot/Makefile	(revision 1049)
@@ -4,5 +4,5 @@
 USE_DT           ?= 0
 DTS              ?= platform.dts
-HARD_CONFIG_PATH ?= ../../../giet_vm
+HARD_CONFIG_PATH ?= ../../../almos-mkh
 MAKECMDGOALS     ?= none
 BS_PROC          ?= 0
Index: trunk/softs/tsar_boot/include/defs.h
===================================================================
--- trunk/softs/tsar_boot/include/defs.h	(revision 1048)
+++ trunk/softs/tsar_boot/include/defs.h	(revision 1049)
@@ -45,6 +45,6 @@
 #endif
 
-#ifndef SEG_XCU_BASE
-#   error "SEG_XCU_BASE constant must be defined in the hard_config.h file"
+#ifndef SEG_ICU_BASE
+#   error "SEG_ICU_BASE constant must be defined in the hard_config.h file"
 #endif
 
Index: trunk/softs/tsar_boot/src/reset.S
===================================================================
--- trunk/softs/tsar_boot/src/reset.S	(revision 1048)
+++ trunk/softs/tsar_boot/src/reset.S	(revision 1049)
@@ -97,4 +97,5 @@
 
 #if USE_32BIT
+
     /*** VERSION 1 : 32 bits ***/
 
@@ -106,5 +107,5 @@
      * In each cluster, the XICU base address depends on the cluster_xy
      */
-    la      t3,     SEG_XCU_BASE      /* t3 <= ICU base address             */
+    la      t3,     SEG_ICU_BASE      /* t3 <= ICU base address             */
     li      t4,     1                 /* t4 <= 1                            */
     sll     t4,     t4,     X_WIDTH   /* t4 <= 1 << X_WIDTH                 */
@@ -136,5 +137,7 @@
     sllv    t4,     t4,     t1       /* Set XICU[MSK_WTI][INDEX][local_id]  */
     sw      t4,     0(t5)            /* XICU[MSK_WTI][INDEX] <= t4          */
+
 #else
+
     /*** VERSION 2 : 40 bits ***/
 
@@ -144,5 +147,5 @@
      * In each cluster, the XICU base address depends on the cluster_xy
      */
-    la      t3,     SEG_XCU_BASE      /* t3 <= ICU base address             */
+    la      t3,     SEG_ICU_BASE      /* t3 <= ICU base address             */
     move    t4,     t1                /* t4 <= local_id                     */
     li      t5,     IRQ_PER_PROCESSOR /* t5 <= IRQ_PER_PROCESSOR            */
@@ -163,4 +166,5 @@
     sw      t4,     0(t5)            /* XICU[MSK_WTI][INDEX] <= t4          */
     mtc2    zero,   CP2_PADDR_EXT    /* reset PADDR extension               */
+
 #endif
 

Index: trunk/softs/tsar_boot/drivers/reset_tty.c
===================================================================
--- trunk/softs/tsar_boot/drivers/reset_tty.c	(revision 1048)
+++ trunk/softs/tsar_boot/drivers/reset_tty.c	(revision 1049)
@@ -11,9 +11,9 @@
 #include <defs.h>
 
 #ifndef SEG_TTY_BASE
 #   error "SEG_TTY_BASE constant must be defined in the hard_config.h file"
 #endif
 
-static int* const tty_address = (int* const)SEG_TTY_BASE;
+static int* const tty_address = (int* const)SEG_TXT_BASE;
 
 enum tty_registers {
@@ -11,9 +11,9 @@
 #include <defs.h>
 
-#ifndef SEG_TTY_BASE
-#   error "SEG_TTY_BASE constant must be defined in the hard_config.h file"
+#ifndef SEG_TXT_BASE
+#   error "SEG_TXT_BASE constant must be defined in the hard_config.h file"
 #endif
 